```{include} ../../README.md

```

```{toctree}
---
maxdepth: 2
caption: Getting Started
hidden:
---
usage
contributing
api
```

## Feedback

If you encounter any errors or problems with **cmweather**,
please open an issue at the GitHub http://github.com/openradar/cmweather main repository.
